diff --git a/.circleci/config.yml b/.circleci/config.yml
index 48759d49d51..d876cd99b02 100644
--- a/.circleci/config.yml
+++ b/.circleci/config.yml
@@ -900,7 +900,7 @@ workflows:
filters:
branches:
only:
- - master
+ - main
jobs:
- nightly_job
diff --git a/bots/dangerfile.js b/bots/dangerfile.js
index d0f6bbfc5a1..428652b8020 100644
--- a/bots/dangerfile.js
+++ b/bots/dangerfile.js
@@ -79,17 +79,17 @@ if (!includesChangelog) {
}
// Warns if the PR is opened against stable, as commits need to be cherry picked and tagged by a release maintainer.
-// Fails if the PR is opened against anything other than `master` or `-stable`.
-const isMergeRefMaster = danger.github.pr.base.ref === 'master';
+// Fails if the PR is opened against anything other than `main` or `-stable`.
+const isMergeRefMaster = danger.github.pr.base.ref === 'main';
const isMergeRefStable = danger.github.pr.base.ref.indexOf('-stable') !== -1;
if (!isMergeRefMaster && isMergeRefStable) {
const title = ':grey_question: Base Branch';
const idea =
- 'The base branch for this PR is something other than `master`. Are you sure you want to merge these changes into a stable release? If you are interested in backporting updates to an older release, the suggested approach is to land those changes on `master` first and then cherry-pick the commits into the branch for that release. The [Releases Guide](https://github.com/facebook/react-native/blob/HEAD/Releases.md) has more information.';
+ 'The base branch for this PR is something other than `main`. Are you sure you want to merge these changes into a stable release? If you are interested in backporting updates to an older release, the suggested approach is to land those changes on `main` first and then cherry-pick the commits into the branch for that release. The [Releases Guide](https://github.com/facebook/react-native/blob/HEAD/Releases.md) has more information.';
warn(`${title} - ${idea}`);
} else if (!isMergeRefMaster && !isMergeRefStable) {
const title = ':exclamation: Base Branch';
const idea =
- 'The base branch for this PR is something other than `master`. [Are you sure you want to target something other than the `master` branch?](https://reactnative.dev/docs/contributing.html#pull-requests)';
+ 'The base branch for this PR is something other than `main`. [Are you sure you want to target something other than the `main` branch?](https://reactnative.dev/docs/contributing.html#pull-requests)';
fail(`${title} - ${idea}`);
}
diff --git a/bots/report-bundle-size.js b/bots/report-bundle-size.js
index 29e03d60a85..e70004d44e3 100644
--- a/bots/report-bundle-size.js
+++ b/bots/report-bundle-size.js
@@ -25,7 +25,7 @@ const datastore = require('./datastore');
const {createOrUpdateComment} = require('./make-comment');
/**
* Generates and submits a comment. If this is run on master branch, data is
* committed to the store instead.
* @param {{
'android-hermes-arm64-v8a'?: number;
@@ -47,7 +47,7 @@ async function reportSizeStats(stats, replacePattern) {
);
const collection = datastore.getBinarySizesCollection(store);
- if (GITHUB_REF === 'master') {
+ if (GITHUB_REF === 'main') {
// Ensure we only store numbers greater than zero.
const validatedStats = Object.keys(stats).reduce((validated, key) => {
const value = stats[key];
@@ -25,7 +25,7 @@ const datastore = require('./datastore');
const {createOrUpdateComment} = require('./make-comment');
/**
- * Generates and submits a comment. If this is run on master branch, data is
+ * Generates and submits a comment. If this is run on main branch, data is
* committed to the store instead.
* @param {{